@@ -24,8 +24,17 @@
 
 getSis<-function(tree,n,printZoom=TRUE)
 {
+
   #require(ape)
   #require(geiger)
+
+  if(!identical(tree$tip.label,tips(tree,(Ntip(tree)+1)))){
+    data.frame(tree$tip.label,N=seq(1,Ntip(tree)))->dftips
+    tree$tip.label<-tips(tree,(Ntip(tree)+1))
+    data.frame(dftips,Nor=match(dftips[,1],tree$tip.label))->dftips
+    tree$edge[match(dftips[,2],tree$edge[,2]),2]<-dftips[,3]
+  }
+
   if(class(n)=="character"){
     which(tree$tip.label==n)->n}
   tree$edge[which(tree$edge[,2]==n),1]->mom
